==> opencpn-4.0.0.tar.gz: OpenCPN-4.0.0/include/emboss_data.h <==
/******************************************************************************
 *
 * Project:  OpenCPN
 *
 ***************************************************************************
 *   Copyright (C) 2013 by David S. Register                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 ***************************************************************************
 */

#ifndef __EMBOSS_DATA_H__
#define __EMBOSS_DATA_H__

#include "dychart.h"

class emboss_data
{
      public:
            emboss_data(){ pmap = NULL; gltexind = 0; }
            ~emboss_data(){ free(pmap); }

            int         *pmap;
            int         width;
            int         height;
            int         x, y;

            GLuint      gltexind;
            int         glwidth, glheight; // next power of 2 larger than width/height
};

#endif

==> opencpn-4.4.0.tar.gz: OpenCPN-4.4.0/include/emboss_data.h <==
/******************************************************************************
 *
 * Project:  OpenCPN
 *
 ***************************************************************************
 *   Copyright (C) 2013 by David S. Register                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 ***************************************************************************
 */

#ifndef __EMBOSS_DATA_H__
#define __EMBOSS_DATA_H__

#include "dychart.h"

class emboss_data
{
      public:
            emboss_data(){ pmap = NULL; gltexind = 0; }
            ~emboss_data(){ free(pmap); }

            int         *pmap;
            int         width;
            int         height;
            int         x, y;

            unsigned int      gltexind;
            int         glwidth, glheight; // next power of 2 larger than width/height
};

#endif
